@@ -1,16 +1,16 @@
 package Net::DNS::Parameters;
 
 #
-# $Id: Parameters.pm 1381 2015-08-25 07:36:09Z willem $
+# $Id: Parameters.pm 1439 2015-12-07 10:37:41Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1381 $)[1];
+$VERSION = (qw$LastChangedRevision: 1439 $)[1];
 
 
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2015-07-26)
+##	(last updated 2015-12-01)
 ##
 ################################################
 
@@ -98,6 +98,7 @@ use vars qw( %typebyname %typebyval );
 	NSEC3	   => 50,					# RFC5155
 	NSEC3PARAM => 51,					# RFC5155
 	TLSA	   => 52,					# RFC6698
+	SMIMEA	   => 53,					# draft-ietf-dane-smime
 	HIP	   => 55,					# RFC5205
 	NINFO	   => 56,					#
 	RKEY	   => 57,					#
@@ -187,6 +188,9 @@ use vars qw( %ednsoptionbyname %ednsoptionbyval );
 	'CLIENT-SUBNET' => 8,					# draft-vandergaast-edns-client-subnet
 	EXPIRE		=> 9,					# RFC7314
 	COOKIE		=> 10,					# draft-ietf-dnsop-cookies
+	'TCP-KEEPALIVE' => 11,					# draft-ietf-dnsop-edns-tcp-keepalive
+	PADDING		=> 12,					# draft-mayrhofer-edns0-padding
+	CHAIN		=> 13,					# draft-ietf-dnsop-edns-chain-query
 	);
 %ednsoptionbyval = reverse %ednsoptionbyname;
 %ednsoptionbyname = ( %ednsoptionbyname, map /\D/ ? lc($_) : $_, %ednsoptionbyname );
