@@ -1,10 +1,10 @@
 package Net::DNS::RR::MR;
 
 #
-# $Id: MR.pm 1390 2015-09-11 11:42:11Z willem $
+# $Id: MR.pm 1406 2015-10-05 08:25:49Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1390 $)[1];
+$VERSION = (qw$LastChangedRevision: 1406 $)[1];
 
 
 use strict;
@@ -56,7 +56,7 @@ sub newname {
 	my $self = shift;
 
 	$self->{newname} = new Net::DNS::DomainName1035(shift) if scalar @_;
-	$self->{newname}->name if defined wantarray && $self->{newname};
+	$self->{newname}->name if $self->{newname};
 }
 
 
