@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC3;
 
 #
-# $Id: NSEC3.pm 1370 2015-07-01 13:48:40Z willem $
+# $Id: NSEC3.pm 1389 2015-09-09 13:09:43Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1370 $)[1];
+$VERSION = (qw$LastChangedRevision: 1389 $)[1];
 
 
 use strict;
@@ -20,7 +20,6 @@ Net::DNS::RR::NSEC3 - DNS NSEC3 resource record
 use integer;
 
 use Carp;
-use MIME::Base32;
 
 use base qw(Exporter);
 use vars qw(@EXPORT_OK);
@@ -48,21 +47,21 @@ my %digest = (
 	my %digestbyname = map { s /[^A-Za-z0-9]//g; $_ } @digestbyalias, @digestbyname, @digestbynum;
 
 
-	sub digestbyname {
+	sub _digestbyname {
 		my $name = shift;
 		my $key	 = uc $name;				# synthetic key
 		$key =~ s /[^A-Z0-9]//g;			# strip non-alphanumerics
 		$digestbyname{$key} || croak "unknown digest type $name";
 	}
 
-	sub digestbyval {
+	sub _digestbyval {
 		my $value = shift;
 		$digestbyval{$value} || return $value;
 	}
 }
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -70,20 +69,19 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 	my $ssize = unpack "\@$offset x4 C", $$data;
 	@{$self}{qw(algorithm flags iterations saltbin)} = unpack "\@$offset CCnx a$ssize", $$data;
 	$offset += 5 + $ssize;
-	my $hsize = unpack "\@$offset C",	  $$data;
-	my $hname = unpack "\@$offset x a$hsize", $$data;
-	$self->hnxtname( MIME::Base32::encode_09AV $hname, '' );
+	my $hsize = unpack "\@$offset C", $$data;
+	$self->{hnxtname} = unpack "\@$offset x a$hsize", $$data;
 	$offset += 1 + $hsize;
 	$self->{typebm} = substr $$data, $offset, ( $limit - $offset );
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{typebm};
+	return '' unless defined $self->{typebm};
 	my $salt = $self->saltbin;
-	my $hash = MIME::Base32::decode_09AV uc( $self->hnxtname );
+	my $hash = $self->{hnxtname};
 	pack 'CCn C a* C a* a*', $self->algorithm, $self->flags, $self->iterations,
 			length($salt), $salt,
 			length($hash), $hash,
@@ -91,18 +89,18 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{hnxtname};
-	my @rdata = $self->algorithm, $self->flags, $self->iterations,
-			$self->salt || '-',
-			$self->hnxtname,
-			$self->typelist;
+	return '' unless defined $self->{typebm};
+	my @rdata = (
+		$self->algorithm, $self->flags, $self->iterations,
+		$self->salt || '-', $self->hnxtname, $self->typelist
+		);
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->algorithm(shift);
@@ -115,10 +113,10 @@ sub parse_rdata {			## populate RR from rdata in argument list
 }
 
 
-sub defaults() {			## specify RR attribute default values
+sub _defaults {				## specify RR attribute default values
 	my $self = shift;
 
-	$self->parse_rdata( 1, 0, 0, '' );
+	$self->_parse_rdata( 1, 0, 0, '' );
 }
 
 
@@ -127,12 +125,12 @@ sub algorithm {
 
 	unless ( ref($self) ) {		## class method or simple function
 		my $argn = pop;
-		return $argn =~ /[^0-9]/ ? digestbyname($argn) : digestbyval($argn);
+		return $argn =~ /[^0-9]/ ? _digestbyname($argn) : _digestbyval($argn);
 	}
 
 	return $self->{algorithm} unless defined $arg;
-	return digestbyval( $self->{algorithm} ) if $arg =~ /MNEMONIC/i;
-	return $self->{algorithm} = digestbyname($arg);
+	return _digestbyval( $self->{algorithm} ) if $arg =~ /MNEMONIC/i;
+	return $self->{algorithm} = _digestbyname($arg);
 }
 
 
@@ -181,8 +179,8 @@ sub saltbin {
 
 sub hnxtname {
 	my $self = shift;
-	return $self->{hnxtname} unless scalar @_;
-	$self->{hnxtname} = lc( shift || '' );
+	$self->{hnxtname} = _decode_base32(shift) if scalar @_;
+	_encode_base32( $self->{hnxtname} ) if defined wantarray;
 }
 
 
@@ -192,14 +190,15 @@ sub covered {
 
 	# first test if the domain name is in the NSEC3 zone.
 	my @domainlabels = new Net::DNS::DomainName($name)->_wire;
-	my ( $ownerhash, @zonelabels ) = map lc($_), $self->{owner}->_wire;
+	my ( $owner, @zonelabels ) = $self->{owner}->_wire;
+	my $ownerhash = _decode_base32($owner);
 
 	foreach ( reverse @zonelabels ) {
-		return 0 unless $_ eq lc( pop(@domainlabels) || return 0 );
+		return 0 unless lc($_) eq lc( pop(@domainlabels) || return 0 );
 	}
 
-	my $namehash = name2hash( $self->algorithm, $name, $self->iterations, $self->saltbin );
-	my $nexthash = $self->hnxtname;
+	my $namehash = _hash( $self->algorithm, $name, $self->iterations, $self->saltbin );
+	my $nexthash = "$self->{hnxtname}";
 
 	unless ( $ownerhash lt $nexthash ) {			# last or only NSEC3 RR
 		return 1 if $namehash lt $nexthash;
@@ -215,19 +214,42 @@ sub match {
 	my $self = shift;
 	my $name = shift;
 
-	my ($ownerhash) = $self->{owner}->_wire;
-	my $namehash = name2hash( $self->algorithm, $name, $self->iterations, $self->saltbin );
+	my $namehash = _hash( $self->algorithm, $name, $self->iterations, $self->saltbin );
 
-	$namehash eq lc($ownerhash);
+	my ($owner) = $self->{owner}->_wire;
+	my $ownerhash = _decode_base32($owner);
+
+	$namehash eq $ownerhash;
 }
 
 
 ########################################
 
-sub hashalgo { &algorithm; }		## historical
+sub _decode_base32 {
+	local $_ = shift || '';
+	tr [0-9a-vA-V] [\000-\037\012-\037];
+	$_ = unpack 'B*', $_;
+	s/000(.....)/$1/g;
+	my $l = length;
+	$_ = substr $_, 0, $l & ~7 if $l & 7;
+	pack 'B*', $_;
+}
 
 
-sub name2hash {
+sub _encode_base32 {
+	local $_ = unpack 'B*', shift;
+	s/(.....)/000$1/g;
+	my $l = length;
+	my $x = substr $_, $l & ~7;
+	my $n = length $x;
+	substr( $_, $l & ~7 ) = join '', '000', $x, '0' x ( 5 - $n ) if $n;
+	$_ = pack( 'B*', $_ );
+	tr [\000-\037] [0-9a-v];
+	return $_;
+}
+
+
+sub _hash {
 	my $hashalg    = shift;
 	my $name       = shift;
 	my $iterations = shift;
@@ -237,7 +259,7 @@ sub name2hash {
 	my ( $object, @argument ) = @$arglist;
 	my $hash = $object->new(@argument);
 
-	my $wirename = new Net::DNS::DomainName2535($name)->encode;
+	my $wirename = new Net::DNS::DomainName($name)->canonical;
 	$iterations++;
 
 	while ( $iterations-- ) {
@@ -246,11 +268,16 @@ sub name2hash {
 		$wirename = $hash->digest;
 	}
 
-	local $_;						# CPAN RT#16528
-	return lc MIME::Base32::encode_09AV( $wirename, '' );	# per RFC4648, 7.
+	return $wirename;
 }
 
 
+sub name2hash { _encode_base32(&_hash); }			# uncoverable pod
+
+
+sub hashalgo { &algorithm; }					# uncoverable pod
+
+
 1;
 __END__
 
@@ -358,7 +385,7 @@ The Type List identifies the RRset types that exist at the domain name
 matched by the NSEC3 RR.  When called in scalar context, the list is
 interpolated into a string.
 
-=head2 covered, matched
+=head2 covered, match
 
     print "covered" if $rr->covered{'example.foo'}
 
