@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC3PARAM;
 
 #
-# $Id: NSEC3PARAM.pm 1362 2015-06-23 08:47:14Z willem $
+# $Id: NSEC3PARAM.pm 1390 2015-09-11 11:42:11Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1362 $)[1];
+$VERSION = (qw$LastChangedRevision: 1390 $)[1];
 
 
 use strict;
@@ -20,7 +20,7 @@ Net::DNS::RR::NSEC3PARAM - DNS NSEC3PARAM resource record
 use integer;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -29,24 +29,24 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{algorithm};
-	my $salt = $self->{saltbin};
+	return '' unless defined $self->{algorithm};
+	my $salt = $self->saltbin;
 	pack 'CCnCa*', @{$self}{qw(algorithm flags iterations)}, length($salt), $salt;
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{algorithm};
+	return '' unless defined $self->{algorithm};
 	join ' ', $self->algorithm, $self->flags, $self->iterations, $self->salt || '-';
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->algorithm(shift);
@@ -99,7 +99,7 @@ sub saltbin {
 
 ########################################
 
-sub hashalgo { &algorithm; }		## historical
+sub hashalgo { &algorithm; }					# uncoverable pod
 
 
 1;
