@@ -1,10 +1,10 @@
 package Net::DNS::RR::SSHFP;
 
 #
-# $Id: SSHFP.pm 1370 2015-07-01 13:48:40Z willem $
+# $Id: SSHFP.pm 1390 2015-09-11 11:42:11Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1370 $)[1];
+$VERSION = (qw$LastChangedRevision: 1390 $)[1];
 
 
 use strict;
@@ -22,7 +22,7 @@ use integer;
 use constant BABBLE => defined eval { require Digest::BubbleBabble; };
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -31,25 +31,25 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{fpbin};
+	return '' unless defined $self->{fpbin};
 	pack 'C2 a*', @{$self}{qw(algorithm fptype fpbin)};
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{fpbin};
+	return '' unless defined $self->{fpbin};
 	my @babble = BABBLE ? ( join '', ';', $self->babble, "\n" ) : ();
 	my @fprint = split /(\S{64})/, $self->fp;
-	my @rdata = $self->algorithm, $self->fptype, @fprint, @babble;
+	my @rdata = ( $self->algorithm, $self->fptype, @fprint, @babble );
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->algorithm(shift);
@@ -137,6 +137,8 @@ construct the public key.
 The 8-bit fingerprint type number describes the message-digest
 algorithm used to calculate the fingerprint of the public key.
 
+=head2 fingerprint
+
 =head2 fp
 
     $fp = $rr->fp;
